/*$Id: e_aux.h,v 17.1 2000/02/19 08:51:13 al Exp $ -*- C++ -*-
 * helper functions, etc., that sort of belong to circuit elements
 */
#ifndef E_AUX_H
#define E_AUX_H
#include "e_node.h"
#include "m_matrix.h"
/*--------------------------------------------------------------------------*/
class node_t;
/*--------------------------------------------------------------------------*/
#if defined(COMPILE_TEMPLATES)
  #error untested
  #include "e_aux.cc"
#else
  template <class T>
  T port_impedance(const node_t& n1, const node_t& n2,
		   BSMATRIX<T>& mat, const T& parallel);
#endif
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
#endif
